@@ -189,7 +189,7 @@ eval_symbol_colors_wide (ChafaCanvas *canvas, ChafaWorkCell *wcell_a, ChafaWorkC
 }
 
 static gint
-calc_error_plain (const ChafaPixel *block, const ChafaColorPair *color_pair, const guint8 *cov)
+calc_cell_error_plain (const ChafaPixel *block, const ChafaColorPair *color_pair, const guint8 *cov)
 {
     gint error = 0;
     gint i;
@@ -243,15 +243,15 @@ eval_symbol_error (const ChafaWorkCell *wcell,
 
 #ifdef HAVE_AVX2_INTRINSICS
     if (chafa_have_avx2 ())
-        error = calc_error_avx2 (wcell->pixels, &pair, sym->mask_u32);
+        error = chafa_calc_cell_error_avx2 (wcell->pixels, &pair, sym->mask_u32);
     else
 #endif
 #ifdef HAVE_SSE41_INTRINSICS
     if (chafa_have_sse41 ())
-        error = calc_error_sse41 (wcell->pixels, &pair, covp);
+        error = chafa_calc_cell_error_sse41 (wcell->pixels, &pair, covp);
     else
 #endif
-        error = calc_error_plain (wcell->pixels, &pair, covp);
+        error = calc_cell_error_plain (wcell->pixels, &pair, covp);
 
     eval->error = error;
 }
@@ -378,8 +378,6 @@ pick_symbol_and_colors_slow (ChafaCanvas *canvas,
     for (i = 0; canvas->config.symbol_map.symbols [i].c != 0; i++)
         eval_symbol (canvas, wcell, i, &best_symbol, &best_eval);
 
-    chafa_leave_mmx ();  /* Make FPU happy again */
-
     /* Output */
 
     g_assert (best_symbol >= 0);
@@ -414,8 +412,6 @@ pick_symbol_and_colors_wide_slow (ChafaCanvas *canvas,
     for (i = 0; canvas->config.symbol_map.symbols2 [i].sym [0].c != 0; i++)
         eval_symbol_wide (canvas, wcell_a, wcell_b, i, &best_symbol, &best_eval);
 
-    chafa_leave_mmx ();  /* Make FPU happy again */
-
     /* Output */
 
     g_assert (best_symbol >= 0);
@@ -479,8 +475,6 @@ pick_symbol_and_colors_fast (ChafaCanvas *canvas,
     for (i = 0; i < n_candidates; i++)
         eval_symbol (canvas, wcell, candidates [i].symbol_index, &best_symbol, &best_eval);
 
-    chafa_leave_mmx ();  /* Make FPU happy again */
-
     /* Output */
 
     g_assert (best_symbol >= 0);
@@ -550,8 +544,6 @@ pick_symbol_and_colors_wide_fast (ChafaCanvas *canvas,
         eval_symbol_wide (canvas, wcell_a, wcell_b, candidates [i].symbol_index,
                           &best_symbol, &best_eval);
 
-    chafa_leave_mmx ();  /* Make FPU happy again */
-
     /* Output */
 
     g_assert (best_symbol >= 0);
@@ -1419,7 +1411,7 @@ ChafaCanvas *
 chafa_canvas_new (const ChafaCanvasConfig *config)
 {
     ChafaCanvas *canvas;
-    gdouble dither_intensity = 1.0;
+    gfloat dither_intensity = 1.0f;
 
     if (config)
     {
